@@ -55,9 +55,6 @@ class MDSimulation():
     coordinates: unit.Quantity or mdtraj.Trajectory, optional
         Alternate coordiantes to be used if parmed_structure coordinates aren't going to be used
 
-    velocities: numpy array, optional
-        Velociites to be used for restarting sim from previous simulation
-
     box_vectors: unit.Quantity, optional
         Box vectors to be used for simulation. If not specified box vectors are taken from parmed_structure
 
@@ -127,7 +124,7 @@ class MDSimulation():
     """
 
     def __init__(self, parmed_structure, coordinates=None,
-                 velocities=None, box_vectors=None,
+                 box_vectors=None,
                  cwd=None, centering=False,
                  temperature=300 * unit.kelvin, pressure=1 * unit.atmosphere, membrane=False,
                  integrator_type='Langevin', platform_name=None, nonbonded_method='PME', nonbonded_cutoff=1 * unit.nanometer,
@@ -163,13 +160,6 @@ class MDSimulation():
 
         self.coordinates = parmed_structure.coordinates
 
-        if velocities is not None:
-            self.velocities = velocities
-        elif parmed_structure.velocities is not None:
-            self.velocities = parmed_structure.velocities
-        else:
-            self.velocities = None
-
         if box_vectors is not None:
             print('using box vectors specified at input')
             self.box_vectors = box_vectors
@@ -246,11 +236,6 @@ class MDSimulation():
         if len(parmed_structure.atoms) != len(self.positions):
             raise ValueError('Number of coordinates does not match number of atoms')
 
-        # match num velocities to num coords
-        if self.velocities is not None:
-            if len(self.velocities) != len(self.positions):
-                raise ValueError('Number of velocities does not match number of coordinates')
-
         if membrane and pressure == None:
             print('WARNING - membrane simulations without pressure controls are not recommended')
 
@@ -587,12 +572,8 @@ class MDSimulation():
         if self.box_vectors is not None:
             self.simulation.context.setPeriodicBoxVectors(self.box_vectors[0], self.box_vectors[1], self.box_vectors[2])
 
-        if self.velocities is not None:
-            print('found velocities, restarting from previous simulation')
-            self.simulation.context.setVelocities(self.velocities)
-        else:
-            print('assigning random velocity distribution with temperature {}'.format(self.temperature))
-            self.simulation.context.setVelocitiesToTemperature(self.temperature)
+        print('assigning random velocity distribution with temperature {}'.format(self.temperature))
+        self.simulation.context.setVelocitiesToTemperature(self.temperature)
 
         if self.atoms_to_restrain is not None:
             self.set_positional_restraints(self.atoms_to_restrain, self.restraint_weight)
@@ -792,23 +773,20 @@ class MDSimulation():
             self.simulation.reporters.append(traj_reporter)
 
     def update_parmed(self):
-        """ updates the parmed object with velocities, coordinates, positions, box vectors,
-            coordinates and current potential energy are updated to the MDSimulation object
+        """ updates the parmed object with coordinates, positions, box vectors,
+            and current potential energy
 
         """
         state = self.simulation.context.getState(getPositions=True,
-                                                 getVelocities=True,
                                                  getEnergy=True,
                                                  enforcePeriodicBox=self.wrap_state_coords)
 
         current_positions = state.getPositions()
-        current_velocities = state.getVelocities()
         current_box = state.getPeriodicBoxVectors()
         self.energy = state.getPotentialEnergy()
 
         self.coordinates = np.array(current_positions.value_in_unit(unit.nanometer))
         self.parmed_structure.positions = current_positions
-        self.parmed_structure.velocities = current_velocities
         if self.box_vectors is not None:
             self.parmed_structure.box_vectors = current_box
         self.positions = current_positions
@@ -860,7 +838,7 @@ class MDSimulation():
         Returns
         -------
         parmed_structure
-            parmed_strcutre with updated coordinates, positions, box_vectors, and velocities if generated
+            parmed_strcutre with updated coordinates, positions, box_vectors
 
          """
 
