@@ -22,7 +22,8 @@ class SegmentMappingSim(MetadynamicSimulation):
     intervals until the distance CV has reached the value of the unbound_distance variable.
 
     Once the distance is reached, suitable (equidistant in CV distance space) frames are chosen to represent the
-    unbinding pathway and used as seeds for a sequential multiple walkers metaD run.
+    unbinding pathway and used as seeds for a sequential multiple walkers metaD run. If multiple CVs are desired
+    one can use the scan_CV_list keyword to submit a list of CV_lists and each scan will use a different CV definition
 
     Params
 
@@ -46,7 +47,7 @@ class SegmentMappingSim(MetadynamicSimulation):
                  time_per_iteration =10 * unit.nanosecond,
                  run_scans=True, run_production=True, input_scan_times=None, input_segment_coords=None,
                  max_iterations=15, max_coverage_criteria=.5, convergence_criteria=.1,
-                 retain_scan_bias=True,
+                 retain_scan_bias=True, scan_CV_list=None,
                  **kwargs):
 
         super().__init__(**kwargs)
@@ -56,6 +57,7 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.num_segs = num_segs_per_replica
         self.scan_bias = scan_bias
         self.scan_time = scan_time
+        self.scan_CV_list = scan_CV_list
         self.scan_bias_freq = int(scan_bias_freq/self.step_length)
         self.scan_bias_height = scan_bias_height
         self.max_scan_time = max_scan_time
@@ -68,13 +70,14 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.run_production_bool = run_production
         self.input_scan_times = input_scan_times
         self.input_segment_coords = input_segment_coords
+        #TODO come up with better handling of CV2_target range, make it automated as default
+        # but still handle the 1CV case
         self.CV2_target_range = CV2_target_range
         self.max_iterations = max_iterations
         self.retain_scan_bias = retain_scan_bias
         self.max_coverage_criteria = max_coverage_criteria
         self.convergence_criteria = convergence_criteria
 
-
         #sanity checks
         if not self.run_scans_bool and self.run_production_bool:
             if self.input_segment_coords==None or self.input_scan_times==None:
@@ -90,6 +93,14 @@ class SegmentMappingSim(MetadynamicSimulation):
                 raise ValueError("""input_segment_coords should be a list of lists, 
                 where the inner lists are coordinates in nm without units""")
 
+        if scan_CV_list is not None and retain_scan_bias==True:
+            print('WARNING, found list of scan CVs but bias is being retained. Be careful about how these runs are interpreted')
+
+        if scan_CV_list is not None:
+            if len(scan_CV_list)!=num_replicas:
+                raise ValueError('scan_CV_list must be the same length as the number of replicas if used.')
+
+
         for cv in self.CV_list:
             if cv[0]=='Distance' and cv[4]<self.unbound_distance:
                 self.unbound_distance=cv[4]
@@ -128,6 +139,14 @@ class SegmentMappingSim(MetadynamicSimulation):
             for i in range(self.num_replicas):
 
                 if self.retain_scan_bias==False:
+                    pattern = re.compile('bias(.*)\.npy')
+                    matches = [pattern.match(filename) for filename in os.listdir(self.cwd) if
+                               pattern.match(filename) != None]
+                    for match in matches:
+                        os.remove(os.path.join(self.cwd, match.string))
+
+                if self.scan_CV_list is not None:
+                    self.CV_list = self.scan_CV_list[i]
                     self._remove_custom_forces()
                     self._build_custom_forces()
 
