@@ -508,4 +508,24 @@ def calc_dG(fes,order,cutoff=.75):
 
 
 def moving_average(x, w):
-    return np.convolve(x, np.ones(w), 'valid') / w
\ No newline at end of file
+    return np.convolve(x, np.ones(w), 'valid') / w
+
+def Ki_to_dG(conc):
+    """
+    accepts Ki with concentration units and returns dG
+    :param conc:
+    :return:
+    """
+    RT = unit.MOLAR_GAS_CONSTANT_R * 300 * unit.kelvin
+    RT = RT.value_in_unit(unit.kilocalorie_per_mole)
+    return np.log(conc/unit.molar) * RT
+
+def dG_to_Ki(dG):
+    """
+    accepts dG (assumed in kcal/mol) returns concentration in molar
+    :param dG:
+    :return:
+    """
+    RT = unit.MOLAR_GAS_CONSTANT_R * 300 * unit.kelvin
+    RT = RT.value_in_unit(unit.kilocalorie_per_mole)
+    return np.e**(dG/RT) * unit.molar
\ No newline at end of file
